@@ -3,11 +3,12 @@ from __future__ import unicode_literals
 import logging
 
 from django.views import generic
-from django.http import HttpResponseBadRequest, HttpResponseRedirect
+from django.http import HttpResponseBadRequest, HttpResponseRedirect, HttpResponse
 from django.core.urlresolvers import reverse
 
 from .backends import get_backends
 from .models import Relation
+from .forms import InvitationForm
 
 from . import settings
 
@@ -37,6 +38,7 @@ class RelationListView(generic.ListView):
     model = Relation
     template_name = 'fairepart/relation_list.html'
     paginate_by = settings.RELATION_LIST_PAGINATE_BY
+    context_object_name = 'relation_list'
 
     def get_queryset(self):
         qs = super(RelationListView, self).get_queryset().filter(from_user=self.request.user)
@@ -51,6 +53,10 @@ class RelationListView(generic.ListView):
     def get_context_data(self, **kwargs):
         context = super(RelationListView, self).get_context_data(**kwargs)
         context['provider'] = self.provider
+        context['from_user'] = self.request.user
+
+        for relation in context[self.context_object_name]:
+            relation.from_user = self.request.user
 
         return context
 
@@ -63,3 +69,29 @@ class RelationListView(generic.ListView):
             ] + template_names
 
         return template_names
+
+
+class InviteView(generic.CreateView):
+    form_class = InvitationForm
+    template_name = 'fairepart/invite.html'
+
+    def get_form_kwargs(self):
+        kwargs = super(InviteView, self).get_form_kwargs()
+        kwargs['user'] = self.request.user
+
+        return kwargs
+
+    def form_valid(self, form):
+        self.object = form.save()
+
+        if self.request.is_ajax():
+            return HttpResponse('Ok')
+
+        return HttpResponseRedirect(self.get_success_url())
+
+    def get_success_url(self):
+        return reverse('fairepart_invite_done')
+
+
+class InviteDoneView(generic.TemplateView):
+    template_name = 'fairepart/invite_done.html'
